<?php

    namespace FederationCLI;

    class Utilities
    {
        /**
         * Parses the shell input into a command and arguments array
         *
         * @param string $input
         * @return array
         */
        public static function parseShellInput(string $input): array
        {
            $parsed = explode(' ', $input);
            $command = array_shift($parsed);
            $args = $parsed;

            return [
                'command' => $command,
                'args' => $args
            ];
        }

        /**
         * Parses a boolean value from a string
         *
         * @param $input
         * @return bool
         */
        public static function parseBoolean($input): bool
        {
            if(is_null($input))
                return false;

            if(is_bool($input))
                return $input;

            if(is_numeric($input))
                return (bool) $input;

            if(is_string($input))
                $input = trim($input);

            switch(strtolower($input))
            {
                case 'true':
                case 'yes':
                case 'y':
                case '1':
                    return true;

                default:
                case 'false':
                case 'no':
                case 'n':
                case '0':
                    return false;
            }
        }

        /**
         * Prompts the user for an input value
         *
         * @param string|null $prompt
         * @param string|null $default_value
         * @return string|null
         */
        public static function promptInput(?string $prompt=null, ?string $default_value=null): ?string
        {
            if($prompt)
                print($prompt . ' ');

            $input = trim(fgets(STDIN));

            if(!$input && $default_value)
                $input = $default_value;

            return $input;
        }

        /**
         * Prompts the user for a boolean value
         *
         * @param string|null $prompt
         * @param bool $default_value
         * @return bool
         */
        public static function promptYesNo(?string $prompt=null, bool $default_value=false): bool
        {
            if($prompt)
                print($prompt . ' ');

            $input = trim(fgets(STDIN));

            if(!$input && $default_value)
                $input = $default_value;

            return self::parseBoolean($input);
        }
    }