<?php

    namespace FederationLib\Interfaces;

    use FederationLib\Classes\Configuration\CacheServerConfiguration;
    use FederationLib\Classes\Memcached;
    use FederationLib\Classes\Redis;

    interface CacheDriverInterface
    {
        /**
         * Constructs a cache server driver
         *
         * @param CacheServerConfiguration $configuration
         */
        public function __construct(CacheServerConfiguration $configuration);

        /**
         * Returns the configuration for the driver
         *
         * @return CacheServerConfiguration
         */
        public function getConfiguration(): CacheServerConfiguration;

        /**
         * Returns the driver connection instance.
         *
         * @return Redis|Memcached
         */
        public function getConnection(): Redis|Memcached;

        /**
         * Connects to the cache server
         *
         * @return void
         */
        public function connect(): void;

        /**
         * Disconnects from the cache server
         *
         * @return void
         */
        public function disconnect(): void;


    }